==> haskell-text-latin1-0.3.1-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-8QzhrQj50rH24KEI2b93h3
key:                  text-latin1-0.3.1-8QzhrQj50rH24KEI2b93h3
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  89d474beaab3b9cb0de3630490d1e930
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-8QzhrQj50rH24KEI2b93h3
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-Aj5W6XdiqgfFLTrW9uNwGR
    data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
    hashable-1.4.4.0-JPPoH0HitSIaCdulNsJk5 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-24o3vBj9Sro9znrQTchekt
key:                  text-latin1-0.3.1-24o3vBj9Sro9znrQTchekt
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  d5c889ca1d93c2cab5d03820fa7e2629
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-24o3vBj9Sro9znrQTchekt
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BQIgiVKdDDDGmlHWIYlRBM
    data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
